"use strict";
/**
 * Copyright 2018 Alexander Sychev
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
Object.defineProperty(exports, "__esModule", { value: true });
var index_1 = require("./index");
var assert = require("assert");
function throwsExceptionWithMessage(testCase, message) {
    var errorMessage;
    var wasThrown;
    try {
        testCase();
        wasThrown = false;
    }
    catch (error) {
        errorMessage = error.message;
        wasThrown = true;
    }
    return wasThrown && errorMessage === message;
}
describe('Function "isRadixValue" returns "true" for all integer values from "MIN_RADIX_VALUE" to "MAX_RADIX_VALUE"', function () {
    for (var radix = index_1.MIN_RADIX_VALUE; radix <= index_1.MAX_RADIX_VALUE; radix++) {
        it("isRadixValue(" + radix + ") === true", function () {
            assert(index_1.isRadixValue(index_1.MIN_RADIX_VALUE) === true);
        });
    }
});
describe('Function "isRadixValue returns "false" to another values', function () {
    it('Not numeric argument returns "false"', function () {
        assert(index_1.isRadixValue({}) === false);
    });
    it('Float argument returns "false"', function () {
        assert(index_1.isRadixValue(12.92) === false);
    });
    it('Integer smaller than "MIN_RADIX_VALUE" returns "false"', function () {
        assert(index_1.isRadixValue(1) === false);
    });
    it('Integer bigger than "MAX_RADIX_VALUE" returns "false"', function () {
        assert(index_1.isRadixValue(38) === false);
    });
});
describe('Check decimals converting by "convert" function', function () {
    it('Decimal "10" converts to binary "1010"', function () {
        assert(index_1.convert(10, 10, 2) === '1010');
    });
    it('Decimal "10" converts to hex "A"', function () {
        assert(index_1.convert(10, 10, 16) === 'A');
    });
});
describe('Check binaries converting by "convert" function', function () {
    it('Binary "1010" converts to decimal "10"', function () {
        assert(index_1.convert('1010', 2, 10) === '10');
    });
    it('Decimal "1010" converts to hex "A"', function () {
        assert(index_1.convert('1010', 2, 16) === 'A');
    });
});
describe('Check hex converting by "convert" function', function () {
    it('Hex "A" converts to decimal "10"', function () {
        assert(index_1.convert('A', 16, 10) === '10');
    });
    it('Hex "A" converts to binary "1010"', function () {
        assert(index_1.convert('A', 16, 2) === '1010');
    });
});
describe('Check exceptions, throwing by "convert" function', function () {
    it('Throws exception if value not a number or string ("convert({}, 10, 2)")', function () {
        assert(throwsExceptionWithMessage(function () { return index_1.convert({}, 10, 2); }, 'First argument ("value") must be number or string'));
    });
    it('Throws exception if number value is not integer ("convert(1.5, 10, 2)")', function () {
        assert(throwsExceptionWithMessage(function () { return index_1.convert(1.5, 10, 2); }, 'Value must be integer'));
    });
    it('Throws exception if radix to convert from is not correct ("convert(10, 0, 2)")', function () {
        assert(throwsExceptionWithMessage(function () { return index_1.convert(10, 0, 2); }, 'Radix to convert from is not a radix value (integer from 2 to 36)'));
    });
    it('Throws exception if radix to convert to is not correct ("convert(10, 10, 37)")', function () {
        assert(throwsExceptionWithMessage(function () { return index_1.convert(10, 10, 37); }, 'Radix to convert to is not a radix value (integer from 2 to 36)'));
    });
    it('Throws exception if numeric tries to convert not from decimal system ("convert(12, 2, 16)")', function () {
        assert(throwsExceptionWithMessage(function () { return index_1.convert(12, 2, 16); }, 'Value with type "number" can be converted only from decimal system'));
    });
});
